# Copyright The Caikit Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Third Party
import grpc

# Local
from caikit.runtime.types.caikit_runtime_exception import CaikitRuntimeException


class AbortedException(CaikitRuntimeException):
    """Exception raised when work was aborted.

    Args:
        message: Because Exceptions usually have those
    """

    def __init__(self, message: str = None):
        if not message:
            message = (
                "Work in this thread was aborted by a context manager. "
                "This is usually due to a client timeout or cancellation."
            )
        super().__init__(grpc.StatusCode.ABORTED, message)
